﻿PROC GLOBAL
{+---------------------------------------------------------------------------+}
{+                                                                           +}
{+   Guidelines February 21, 2017     -       Version 2.0.0 of 04/07/2017    +}
{+                                                                           +}
{+   CHAPTER 1.  INTRODUCTION                                                +}
{+                                                                           +}
{+   1.1   Results of the household and individual interviews                +}
{+                                                                           +}
{+   CHAPTER 2.  HOUSEHOLD POPULATION AND HOUSING CHARACTERISTICS            +}
{+   2.1.1  Household drinking water                                         +}
{+   2.1.2  Drinking water according to region and wealth                    +}
{+   2.1.3  Treatment of household drinking water                            +}
{+   2.2    Availability of water                                            +}
{+   2.3.1  Household sanitation facilities                                  +}
{+   2.3.2  Sanitation facility type according to region and wealth          +}
{+   2.4    Housing characteristics                                          +}
{+   2.5    Household possessions                                            +}
{+   2.6    Wealth quintiles                                                 +}
{+   2.7    Hand washing                                                     +}
{+   2.8    Household population by age, sex, and residence                  +}
{+   2.8a   Population pyramid (Working table for Figure 2.1)                +}
{+   2.9    Household composition                                            +}
{+   2.10   Children's living arrangements and orphanhood                    +}
{+   2.11   Birth registration of children under age five                    +}
{+   2.12.1 Education attainment of female household population              +}
{+   2.12.2 Education attainment of male household population                +}
{+   2.13   School attendance ratios                                         +}
{+   2.13a  Age-specific attendance rates (for Figure 2.2)                   +}
{+   2.14   Grade repetition and dropout rates      - not a core table -     +}   
{+---------------------------------------------------------------------------+}

  set explicit;

  numeric i, imin, imax, imax1, itot, itot1, itot2, itot3, j, jmin, jmax, jtot, jtot1, jtot2, jtot3, k;
  numeric rweight, mothaliv, livemoth, fathaliv, livefath, mothdead, fathdead;
  numeric colt210, imean, maxeduc, jmed, jreg, ifem, sdgsex;
  numeric ginicoeff, wlthrng, wlthgrp, popdist, wlthdist, wlthgrps, idx;
  numeric yeareduc, mntheduc, cmceduci, cmceducf, ageatsch, xtemp, cmctemp;
  numeric grdcur, grdprev;

  array cmcbirth(100);       { children's CMC of birth from level 2 to level 1 to properly calculate NAR and GAR in table 2.13 }

  array ScoreMin(100);       { stores the minimum score for ecah background category for which the Gini coefficient is calculated }
  array ScoreMax(100);       { stores the maximum score for ecah background category for which the Gini coefficient is calculated }

  crosstab float(0) txxx unweight runday+runmonth+runyear
    exclude(specval, rowzero, colzero, totals, percents)
    title( "Tables for chapter 2, Turkey DHS 2018" );

  crosstab float(0) t101  hhresult+hhrate+wresult+wrate hv025w+total
    exclude(rowzero,colzero,percents,totals,specval)
   title( "Table 1.1  Results of the household and individual interviews"," ",
          "Number of households, number of interviews, and response rates,",
          "according to residence (unweighted), Turkey DHS 2018" )
    stub( "Result" );

  crosstab float(1) t2011 hv201w+total+hv204w+total+bastreat+limtreat+tothh2 hhandpop*(hv025w+total)
    exclude(rowzero,colzero,percents,totals,specval)
    title( "Table 2.1.1 Household drinking water", "",
           "Percent distribution of households and de jure population by source of drinking water", 
           "and by time to obtain drinking water; percentage of households and de jure population", 
           "with basic drinking water service and percentage with limited drinking water service,", 
           "according to residence, Turkey DHS 2018 " )
     stub( "Characteristic" );

  crosstab float(1) t2012 hv024w+wreg12+hv270w+total hv201w2+total+bastreat+limtreat+numpers
    exclude(rowzero,colzero,percents,totals,specval)
    title( "Table 2.1.2 Drinking water according to region and wealth", "",
           "Percent distribution of de jure population by drinking water source, percentage of de", 
           "jure population with basic drinking water service, and percentage with limited drinking", 
           "water service, according to region and wealth quintile, Turkey DHS 2018 " )
     stub( "Background characteristic" );


  crosstab float(1) t2031 hv205w1+hv205w3+nofacil+tothh2+hv238aw+tothh3+basfacil+limfacil+tothh2 hhandpop*(hv025w+total)
    exclude(rowzero,colzero,percents,totals,specval)
    title( "Table 2.3.1 Household sanitation facilities"," ",
           "Percent distribution of households and de jure population by type of toilet/latrine facilities,", 
           "percent distribution of households and de jure population with a toilet/latrine facility by", 
           "location of the facility, percentage of households and de jure population with basic sanitation", 
           "services, according to residence,",
           "Turkey DHS 2018" )
     stub( "Type and location of toilet/latrine facility" );
     
  crosstab float(1) t2031a hv205w2+hv205w5+hv205w3a+totnum1 hhandpop*(hv025w+total)
    exclude(rowzero,colzero,percents,totals,specval)
    title( "Table 2.3.1a Household sanitation facilities"," ",
           "Percent distribution of households and de jure population by type of toilet/latrine facilities,", 
           "percent distribution of households and de jure population with a toilet/latrine facility by", 
           "location of the facility, percentage of households and de jure population with basic sanitation", 
           "services, according to residence,",
           "Turkey DHS 2018" )
     stub( "Type and location of toilet/latrine facility" );

  crosstab float(1) t2032 hv024w+wreg12+hv270w+total typesani+total+basfacil+limfacil+numpers
    exclude(rowzero,colzero,percents,totals,specval)
    title( "Table 2.3.2 Sanitation facility type according to region and wealth"," ",
           "Percent distribution of de jure population by type of sanitation, percentage of de jure population", 
           "with basic sanitation service, and percentage with limited sanitation service, according to region", 
           "and wealth quintile, Turkey DHS 2018" )
     stub( "Background characteristic" );

  crosstab float(1) t204 hv206w+total+hv213w+total+hv216w+total+hv241w+total+hv226w+total+solfuel+clnfuel+hv252w+tothh2
                         hhandpop*(hv025w+total)
    exclude(rowzero,colzero,percents,totals,specval)
    title( "Table 2.4  Household characteristics"," ",
           "Percent distribution of households and de jure population by housing characteristics,",
           "and percent distribution by frequency of smoking in the home, according to residence,",
           "Turkey DHS 2018" )
     stub( "Housing characteristic" );

  crosstab float(1) t205 heffects+transp+hv244w+hv246w+tnumber  hv025w+total
    exclude(rowzero,colzero,percents,totals,specval)
    title( "Table 2.5  Household possessions"," ",
           "Percentage of households possessing various household effects, means of transportation,",
           "agricultural land and livestock/farm animals by residence, Turkey DHS 2018" )
     stub( "Possession" );

  crosstab float(1) t206  hv025w+hv024w+wreg12+total hv270w+totnum3+gini
    exclude(rowzero,colzero,percents,totals,specval)
    title( "Table 2.6  Wealth quintiles"," ",
           "Percent distribution of the de jure population by wealth quintiles, and the Gini",
           "coefficient, according to residence and region, Turkey DHS 2018" )
     stub( "Residence/region" );
  crosstab float(3) t206w hv025w+hv024w+wreg12+total wigrp popwlth
    exclude(rowzero,colzero,percents,totals,specval);

  crosstab float(1) t208  hhage1+total+hhagea+total+hhageb+total+adol1019+numpers hv025w1*(hhsex+total)+hhsex+total
    exclude(rowzero,colzero,percents,totals,specval)
   title( "Table 2.8  Household population by age, sex, and residence"," ",
          "Percent distribution of the de facto household population by",
          "age groups, according to sex and residence,",
          "Turkey DHS 2018" )
    stub( "Age");

  crosstab float(0) t208w hsex hv025w
    exclude(rowzero,colzero,specval)
    title( "2.8w de facto population by sex"," ",
           "If there are household members with sex missing, add a footnote to table 2.07" );

  crosstab float(1) t208a hhage1+totnum1 hhsex+total
    exclude(rowzero,colzero,percents,totals,specval)
    title( "Figure 2.1W  Population pyramid (WORKING TABLE ONLY)"," ",
           "Percent distribution of the de facto household population by",
           "5-year age groups, according to sex, Turkey DHS 2018" )
     stub( "Age" );

  crosstab float(1) t209 hv219w+total+hv012w+totmean1+dorphan+sorphan+foster+fostorph+numhh
                         hv025w+total
    exclude(rowzero,colzero,percents,totals,specval)
    title( "Table 2.9  Household composition"," ",
           "Percent distribution of households by sex of head of household",
           "and by household size; mean size of household, and percentage of households",
           "with orphans and foster children under 18 years of age, according to residence,",
           " Turkey DHS 2018" )
     stub( "Characteristic" );

  crosstab float(0) t209w rowt209 hv025w+total 
    exclude(rowzero,colzero,percents,totals,specval);

  crosstab float(1) t210 hhage18+hsex+hv025w+hv024w+wreg12+hv270w+total15+total18
                         colt210a+colt210b+colt210c+colt210d+totperc1+numchild
    exclude(rowzero,colzero,percents,totals,specval)
    title( "Table 2.10  Children's living arrangements and orphanhood"," ",
           "Percent distribution of de jure children under age 18 by",
           "living arrangements and survival status of parents, percentage",
           "of children not living with a biological parent, and percentage",
           "of children with one or both parents dead,",
           "according to background characteristics, Turkey DHS 2018" )
     stub( "Background characteristic" );
  crosstab float(0) t210u hhage18+hsex+hv025w+hv024w+wreg12+hv270w+total15+total18 total
    exclude(rowzero,colzero,percents,totals,specval)
    title( "Table 2.10  Children's living arrangements and orphanhood (Number of un-weighted cases)" )
     stub( "Background characteristic" );

  // crosstab float(1) t211  hhage4+hsex+hv025w+hv024w+wreg12+hv270w+total hv140w+numchild
  
  crosstab float(1) t211  chiage4+sex1+v102w+v101w+wreg12+v190w+total s223w+total+numchild
    exclude(rowzero,colzero,percents,totals,specval)
    title( "Table 2.11 Birth registration of children under age 5"," ",
           "Percentage of de jure children under age 5 whose births are registered",
           "with the civil authorities, according to background characteristics, Turkey DHS 2018" )
     stub( "Background characteristic" );
  crosstab float(0) t211u  chiage4+sex1+v102w+v101w+wreg12+v190w+total total
    exclude(rowzero,colzero,percents,totals,specval)
    title( "Table 2.11 Birth registration of children under age five (Number of un-weighted cases)" )
     stub( "Background characteristic" );

  crosstab float(1) t2121  hhage3+hv025w+hv024w+wreg12+hv270w+total hheduc+totnmed1
    exclude(rowzero,colzero,percents,totals,specval)
    title( "Table 2.12.1 Educational attainment of the female household population"," ",
           "Percent distribution of the de facto female household",
           "population age 6 and over by highest level of schooling",
           "attended or completed and median years completed,",
           "according to background characteristics, Turkey DHS 2018" )
     stub( "Background characteristic" );
  crosstab float(1) t2121w hhage3+hv025w+hv024w+wreg12+hv270w+total educmed
    exclude(rowzero,colzero,percents,totals,specval);
  crosstab float(0) t2121u  hhage3+hv025w+hv024w+wreg12+hv270w+total coltotu
    exclude(rowzero,colzero,percents,totals,specval)
    title( "Table 2.12.1 Educational attainment of the female household population (Number of un-weighted cases)" )
     stub( "Background characteristic" );

  crosstab float(1) t2122  hhage3+hv025w+hv024w+wreg12+hv270w+total hheduc+totnmed1
    exclude(rowzero,colzero,percents,totals,specval)
    title( "Table 2.12.2 Educational attainment of the male household population"," ",
           "Percent distribution of the de facto male household",
           "population age 6 and over by highest level of schooling",
           "attended or completed and median years completed,",
           "according to background characteristics, Turkey DHS 2018" )
     stub( "Background characteristic" );
  crosstab float(1) t2122w hhage3+hv025w+hv024w+wreg12+hv270w+total educmed
    exclude(rowzero,colzero,percents,totals,specval);
  crosstab float(0) t2122u  hhage3+hv025w+hv024w+wreg12+hv270w+total coltotu
    exclude(rowzero,colzero,percents,totals,specval)
    title( "Table 2.12.2 Educational attainment of the male household population (Number of un-weighted cases)" )
     stub( "Background characteristic" );

  crosstab float(1) t213  hv025w+hv024w+wreg12+hv270w+total attrat*(hhsex+total+gparity) schlev
    exclude(rowzero,colzero,percents,totals,specval)
    title( "Table 2.13  School attendance ratios"," ",
           "Net attendance ratios (NAR) and gross attendance ratios (GAR)",
           "for the de facto household population by sex and level of schooling; and the",
           "Gender Parity Index (GPI), according to background characteristics, Turkey DHS 2018" )
     stub( "Background characteristic" );
  crosstab float(0) t213w hv025w+hv024w+wreg12+hv270w+total attrat*(hhsex+total+gparity) schlev
    exclude(rowzero,colzero,percents,totals,specval);

  crosstab float(1) t213a agehhs colt213a hsex
    exclude(rowzero,colzero,percents,totals,specval)
    title( "Figure 2.2W Age-specific attendance rates of the de facto population age 6-24 years (WORKING TABLE ONLY)"," ",
           "Percentage of the de facto household population age 6-24",
           "years attending school, by age and sex, Turkey DHS 2018" );
           
  crosstab float(1) t214 hhsex1+hv025w+hv024w+wreg12+hv270w+total colt214a repdrop
    exclude(rowzero,colzero,percents,totals,specval)
    title( "Table 2.14  Grade repetition and dropout rates "," ",
           "Repetition and dropout rates for the de facto household",
           "population age 6-24 who attended primary school in the previous",
           "school year by school grade, according to",
           "background characteristics, Turkey DHS 2018" )
     stub( "Background characteristic" );   
  crosstab float(1) t214w hhsex1+hv025w+hv024w+wreg12+hv270w+total colt214a repdrop
    exclude(rowzero,colzero,percents,totals,specval)  
     title( "Table 2.14W  Grade repetition and dropout rates (WORKING TABLE ONLY)"," ",           
           "Repetition and dropout rates for the de facto household",
           "population age 6-24, Turkey DHS 2018" );      

PROC RECODE7_FF
preproc

  total    = 0;
  tnumber  = 1;
  numhh    = 1;
  numchild = 1;
  numpers  = 1;
  totmean1 = 0;
  totnmed1 = 1;
  totnum1  = 1;
  totnum3  = 1;
  totnum9  = 1;
  maxeduc  = 15;
  totperc1 = 3;
  tothh2   = 1;

  { !! run application GiniMinMax to obtain the minimums and maximums for the wealth index scores }
  { !! make sure that arrays are initialized with the same index produced by that application     }
  { !! Note that in the initialization below regions 8-11 don't exist                             }
  { *** remove this comment after the values coming from GiniMinMax are copied and pasted
  ScoreMin( 1) = -222285;  ScoreMax( 1) = 407319;   { Total               }
  ScoreMin( 2) = -222285;  ScoreMax( 2) = 303669;   { Residence: Urban    }
  ScoreMin( 3) = -156466;  ScoreMax( 3) = 407319;   { Residence: Rural    }
  ScoreMin( 4) =  -85789;  ScoreMax( 4) = 291999;   { Region   :  1       }
  ScoreMin( 5) = -156466;  ScoreMax( 5) = 237670;   { Region   :  2       }
  ScoreMin( 6) =  -94416;  ScoreMax( 6) = 273493;   { Region   :  3       }
  ScoreMin( 7) = -108586;  ScoreMax( 7) = 407319;   { Region   :  4       }
  ScoreMin( 8) = -203554;  ScoreMax( 8) = 234452;   { Region   :  5       }
  ScoreMin( 9) = -145587;  ScoreMax( 9) = 261429;   { Region   :  6       }
  ScoreMin(10) = -102288;  ScoreMax(10) = 303669;   { Region   :  7       }
  ScoreMin(15) = -222285;  ScoreMax(15) = 261832;   { Region   : 12       }
  ScoreMin(16) =  -89788;  ScoreMax(16) = 282207;   { Region   : 13       }
  ScoreMin(17) = -100214;  ScoreMax(17) = 302198;   { Region   : 14       }
  ScoreMin(18) =  -87069;  ScoreMax(18) = 318995;   { Region   : 15       }
  *** this comment also needs to be removed after copying the results from GiniMinMax    ********       }
 
  ScoreMin( 1) =  -282846; ScoreMax( 1) =   228193;   { Total               }
  ScoreMin( 2) =  -275881; ScoreMax( 2) =   228193;   { Residence: Urban    }
  ScoreMin( 3) =  -282846; ScoreMax( 3) =   224107;   { Residence: Rural    }
  ScoreMin( 4) =  -242229; ScoreMax( 4) =   228193;   { Region   : West     }
  ScoreMin( 5) =  -261327; ScoreMax( 5) =   212774;   { Region   : South    }
  ScoreMin( 6) =  -263429; ScoreMax( 6) =   222185;   { Region   : Central  }
  ScoreMin( 7) =  -215966; ScoreMax( 7) =   207500;   { Region   : North    }
  ScoreMin( 8) =  -282846; ScoreMax( 8) =   169792;   { Region   : East     }
  ScoreMin( 9) =  -228003; ScoreMax( 9) =   225409;   { Region 1            } 
  ScoreMin(10) =  -242224; ScoreMax(10) =   228193;   { Region 2            } 
  ScoreMin(11) =  -242229; ScoreMax(11) =   203068;   { Region 3            } 
  ScoreMin(12) =  -239109; ScoreMax(12) =   224107;   { Region 4            } 
  ScoreMin(13) =  -242445; ScoreMax(13) =   222185;   { Region 5            } 
  ScoreMin(14) =  -261327; ScoreMax(14) =   212774;   { Region 6            } 
  ScoreMin(15) =  -263429; ScoreMax(15) =   190301;   { Region 7            } 
  ScoreMin(16) =  -229193; ScoreMax(16) =   199082;   { Region 8            } 
  ScoreMin(17) =  -215966; ScoreMax(17) =   207500;   { Region 9            } 
  ScoreMin(18) =  -275881; ScoreMax(18) =   168215;   { Region 10           } 
  ScoreMin(19) =  -282846; ScoreMax(19) =   163254;   { Region 11           } 
  ScoreMin(20) =  -264165; ScoreMax(20) =   169792;   { Region 12           } 
    
  
  wlthgrps = 100;          { Divide population into 100 groups for Gini calculations }

  yeareduc = 2018;         { !! year when the country's academic year start based for the survey's year, ask for it to CM }
  mntheduc = 09;           { !! month when the country's academic year start based for the survey's year.  ask for it to CM }
  cmceduci = cmcode( mntheduc, yeareduc );
  seed(101);               { to initiate ramdomization for members age at the beginnig of school year }

  unweight = ( sysparm()[1:1] = "U" );   { 0-Weighted, 1-unweighted }

postproc

  { constructs table to determine whether run is weighted/unweighted }
  txxx(unweight,0) = sysdate( "dd" );      { day   }
  txxx(unweight,1) = sysdate( "mm" );      { month }
  txxx(unweight,2) = sysdate( "yyyy" );    { year  }

  { Table 1.1 processing }
  itot = tblrow( t101, hhrate );         { household response rate }
  t101[itot,*] = t101[itot-1,*] * 100 / t101[itot-2,*];
  itot = tblrow( t101, wrate );          { women response rate }
  t101[itot,*] = t101[itot-1,*] * 100 / t101[itot-2,*];

  { Table 2.1.1 processing }
  itot = tblrow( t2011 );
  imax = itot - 1;
  do i = 0 while i <= imax
    t2011[i,*] = t2011[i,*] * 100 / t2011[itot,*];
  enddo;
  { total source of drinking water }
  imin = tblrow( t2011,  hv201w = 10 );
  imax = tblrow( t2011,  total(1) = 0 ) - 1;
  t2011[imax+1,*] = tblsum( row t2011[imin:imax,*] );
  { total improved source for water }
  imin = tblrow( t2011, hv201w = 10 );
  imax = tblrow( t2011, hv201w = 30 );
  t2011[imin,*] = tblsum( row t2011[imin+1:imax-1,*] );
  { total non-improved source for water }
  imin = tblrow( t2011, hv201w = 30 );
  imax = tblrow( t2011, hv201w = 96 );
  t2011[imin,*] = tblsum( row t2011[imin+1:imax-1,*] );
  { total time to obtain water }
  imin = tblrow( t2011,  total(1) = 0 ) + 1;
  imax = tblrow( t2011,  total(2) = 0 ) - 1;
  t2011[imax+1,*] = tblsum( row t2011[imin:imax,*] );

  { Table 2.1.2 processing }
  jtot = tblcol( t2012 );
  jmax = jtot - 1;
  do j = 0 while j <= jmax
    t2012[*,j] = t2012[*,j] * 100 / t2012[*,jtot];
  enddo;
  jmax = tblcol( t2012, total );
  t2012[*,jmax] = tblsum( column t2012[*,0:jmax-1] );

  { Table 2.3.1 processing }
  { percentages for type of facility }
  itot1 = tblrow( t2031, tothh2(1) );
  imax = itot1 - 2;
  do i = 0 while i <= imax
    t2031[i,*] = t2031[i,*] * 100 / t2031[itot1,*];
  enddo;
  t2031[imax+1,*] = tblsum( row t2031[0:imax,*] );
  { percenatges for location of facility }
  itot2 = tblrow( t2031, tothh3 );
  imax = itot2 - 2;
  do i = itot1+1 while i <= imax
    t2031[i,*] = t2031[i,*] * 100 / t2031[itot2,*];
  enddo;
  t2031[imax+1,*] = tblsum( row t2031[itot1+1:imax,*] );
  { percentages for basic/limited sanitation service  }
  itot3 = tblrow( t2031 );
  imax = itot3 - 2;
  do i = itot2+1 while i <= imax
    t2031[i,*] = t2031[i,*] * 100 / t2031[itot3,*];
  enddo;
  { total - improved sanitation }
  imin = tblrow( t2031, hv205w1 = 0 );
  imax = tblrow( t2031, hv205w1 );
  t2031[imin,*] = tblsum( row t2031[imin+1:imax,*] );
  { total - unimproved sanitation }
  imin = tblrow( t2031, hv205w3 = 0 );
  imax = tblrow( t2031, hv205w3 );
  t2031[imin,*] = tblsum( row t2031[imin+1:imax,*] );

  { Table 2.3.2 processing }
  jtot = tblcol( t2032 );
  jmax = jtot - 1;
  do j = 0 while j <= jmax
    t2032[*,j] = t2032[*,j] * 100 / t2032[*,jtot];
  enddo;
  jmax = tblcol( t2032, total );
  t2032[*,jmax] = tblsum( column t2032[*,0:jmax-1] );


  { Table 2.3.1a processing }
  itot = tblrow( t2031a );
  imax = itot - 2;
  do i = 0 while i <= imax
    t2031a[i,*] = t2031a[i,*] * 100 / t2031a[itot,*];
  enddo;
  t2031a[imax+1,*] = tblsum( row t2031a[0:imax,*] );
  { totals for improved, not shared facility }
  itot1 = tblrow( t2031a, hv205w2 );
  imax  = itot1 - 1;
  t2031a[itot1,*] = tblsum( row t2031a[0:imax,*] );
  { totals for shared facility }
  itot2 = tblrow( t2031a, hv205w5 );
  imax  = itot2 - 1;
  t2031a[itot2,*] = tblsum( row t2031a[itot1+1:imax,*] );
  { totals for non-improved facility }
  itot3 = tblrow( t2031a, hv205w3a );
  imax  = itot3 - 1;
  t2031a[itot3,*] = tblsum( row t2031a[itot2+1:imax,*] );


  { Table 2.4 processing }
  itot = tblrow( t204 );
  imax = itot - 1;
  do i = 0 while i <= imax
    t204[i,*] = t204[i,*] * 100 / t204[itot,*];
  enddo;

  { electricity }
  imin = tblrow( t204,  hv206w   = 1 );
  imax = tblrow( t204,  total(1) = 0 ) - 1;
  t204[imax+1,*] = tblsum( row t204[imin:imax,*] );

  { flooring material }
  imin = tblrow( t204,  total(1) = 0 ) + 1;
  imax = tblrow( t204,  total(2) = 0 ) - 1;
  t204[imax+1,*] = tblsum( row t204[imin:imax,*] );

  { rooms used for sleeping }
  imin = tblrow( t204,  total(2) = 0 ) + 1;
  imax = tblrow( t204,  total(3) = 0 ) - 1;
  t204[imax+1,*] = tblsum( row t204[imin:imax,*] );

  { place for cooking }
  imin = tblrow( t204,  total(3) = 0 ) + 1;
  imax = tblrow( t204,  total(4) = 0 ) - 1;
  t204[imax+1,*] = tblsum( row t204[imin:imax,*] );

  { cooking fuel }
  imin = tblrow( t204,  total(4) = 0 ) + 1;
  imax = tblrow( t204,  total(5) = 0 ) - 1;
  t204[imax+1,*] = tblsum( row t204[imin:imax,*] );

  { frequency of smoking }
  imin = tblrow( t204,  total(5) = 0 ) + 3;
  imax = itot - 2;
  t204[imax+1,*] = tblsum( row t204[imin:imax,*] );
  { write out SDG indicators }
  itot   = tblrow( t204, hv206w = 1 );              { electricity }
  jtot   = tblcol( t204, hhandpop = 2 hv025w = 1 );
  SDGIndicator( "7.1.1", t204(itot,jtot), t204(itot,jtot+1), t204(itot,jtot+2) );
  itot   = tblrow( t204, clnfuel );                 { clean fuel for cooking }
  jtot   = tblcol( t204, hhandpop = 2 hv025w = 1 );
  SDGIndicator( "7.1.2", t204(itot,jtot), t204(itot,jtot+1), t204(itot,jtot+2) );

  { Table 2.5 processing }
  itot = tblrow( t205 );
  imax = itot - 1;
  do i = 0 while i <= imax
    t205[i,*] = t205[i,*] * 100 / t205[itot,*];
  enddo;

  { Table 2.6 processing }
  jtot = tblcol( t206, totnum3 );
  jmax = jtot - 2;
  do j = 0 while j <= jmax
    t206[*,j] = t206[*,j] * 100 / t206[*,jtot];
  enddo;
  t206[*,jmax+1] = tblsum( column t206[*,0:jmax] );
  { Gini coefficient }
  popdist  = 0;
  wlthdist = 1;
  do i = 0 while i <= tblrow(t206)  { loop through all rows }
    { Cumulative population and wealth scores }
    do j = 1 while j <= wlthgrps
      t206w(i,j,popdist ) = t206w(i,j,popdist ) + t206w(i,j-1,popdist );
      t206w(i,j,wlthdist) = t206w(i,j,wlthdist) + t206w(i,j-1,wlthdist);
    enddo;
    { Turn into cumulative proportions }
    do j = 1 while j <= wlthgrps
      t206w(i,j,popdist ) = t206w(i,j,popdist ) / t206w(i,wlthgrps,popdist );
      t206w(i,j,wlthdist) = t206w(i,j,wlthdist) / t206w(i,wlthgrps,wlthdist);
    enddo;
    { Gini = |1-sum((Xk - Xk-1)*(Yk + Yk-1))|, where k=1,...,100, X0=0, Y0=0, X100=100%, Y100=100% }
    ginicoeff = 0;
    do k = 1 while k <= wlthgrps
      { Xk = cumulative population distribution at group k }
      { Yk = cumulative wealth distribution at group k }
      { Sum (Xk-Xk-1) * (Yk + Yk-1) }
      ginicoeff = ginicoeff +
                 ( t206w(i,k,popdist ) - t206w(i,k-1,popdist ) ) *
                 ( t206w(i,k,wlthdist) + t206w(i,k-1,wlthdist) )
    enddo;
    { last instruction for the coefficient formula }
    ginicoeff = (1 - ginicoeff);
    { take absolute value }
    if ginicoeff < 0 then ginicoeff = 0 - ginicoeff endif;
    t206(i,jmax+3) = ginicoeff;
  enddo;

  { Table 2.8 processing }
  itot = tblrow( t208 );
  imax = itot - 1;
  do i = 0 while i <= imax
    t208[i,*] = t208[i,*] * 100 / t208[itot,*];
  enddo;
  { totals for first row panel }
  imax  = tblrow( t208, hhage1 );
  itot1 =  imax + 1;
  t208[itot1,*] = tblsum( row t208[0:imax,*] );
  { totals for second row panel }
  imax  = tblrow( t208, hhagea );
  itot2 =  imax + 1;
  t208[itot2,*] = tblsum( row t208[itot1+1:imax,*] );
  { totals for third row panel }
  imax  = tblrow( t208, hhageb );
  itot3 =  imax + 1;
  t208[itot3,*] = tblsum( row t208[itot2+1:imax,*] );

  { Table 2.8a processing for figure 2.1 }
  itot = tblrow( t208a );
  imax = itot - 2;
  jtot = tblcol( t208a );
  do j = 0 while j <= jtot   { for each column }
    do i = 0 while i <= imax
      t208a(i,j) = t208a(i,j) * 100 / t208a(itot,jtot);
    enddo;
  enddo;
  t208a[imax+1,*] = tblsum( row t208a[0:imax,*] );

  { Table 2.9 processing }
  itot  = tblrow( t209 );
  imax  = itot - 1;
  do i = 0 while i <= imax
    t209[i,*] = t209[i,*] * 100 / t209[itot,*];
  enddo;
  { mean size of households }
  imean = tblrow( t209, totmean1 = 1 );
  t209[imean,*] = t209w[1,*] / t209w[0,*];

  { Table 2.10 processing }
  { add age 0-4 from <2 and 2-4 }
  t210[0,*] = t210[1,*] + t210[2,*];
  jtot = tblcol( t210 );
  jmax = jtot - 4;
  do j = 0 while j <= jmax
    t210[*,j] = t210[*,j] * 100 / t210[*,jtot];
  enddo;
  t210[*,jmax+1] = tblsum( column t210[*,0:jmax] );
  { percentage not living with a biological parent }
  jtot1 = tblcol( t210, totperc1 = 1 );
  jmin  = tblcol( t210, colt210d = 1 );
  jmax  = tblcol( t210, colt210d = 4 );
  t210[*,jtot1] = tblsum( column t210[*,jmin:jmax] );
  { percentage with one or both parents dead }
  t210[*,jtot1+1] = t210[*,jtot1+1] * 100 / t210[*,jtot];
  { check unweighted N's }
  { add age 0-4 from <2 and 2-4 }
  t210u[0,*] = t210u[1,*] + t210u[2,*];
  Col2Dim( "t210", t210, 0,      jtot-4, t210u, 0 );
  Col2Dim( "t210", t210, jtot-2, jtot-1, t210u, 0 );

 
  { Table 2.11 processing }
  { calculate percentages }
  jtot = tblcol( t211 );
  jmax = jtot - 1;
  do j = 0 while j <= jmax
    t211[*,j] = t211[*,j] * 100 / t211[*,jtot];
  enddo;  
  t211[*,jtot-1] = tblsum( column t211[*,0:2] );  
  
  { check unweighted N's }
  Col2Dim( "t211", t211, 0, jtot-1, t211u, 0 );
  { write out SDG indicators }
  itot   = tblrow( t211 );
  sdgsex = tblrow( t211, sex1 = 1 );
  jtot   = tblcol( t211, s223w = 1 );
  SDGIndicator( "16.9.1", t211(sdgsex,jtot), t211(sdgsex+1,jtot), t211(itot,jtot) );

  { Table 2.12.1 processing }
  jtot = tblcol( t2121, totnmed1 = 1 );
  jmax = jtot - 2;
  do j = 0 while j <= jmax
    t2121[*,j] = t2121[*,j] * 100 / t2121[*,jtot];
  enddo;
  t2121[*,jmax+1] = tblsum( column t2121[*,0:jmax] );
  { calculates median }
  jmed = tblcol( t2121, totnmed1 = 2 );
  t2121[*,jmed] = tblmed( discrete column t2121w[*,0:maxeduc] intervals(highest default) );
  { Check for defaults on medians to make them zero }
  itot = tblrow(t2121);
  do i = 0 while i <= itot
    if t2121(i,jmed) = default then t2121(i,jmed) = 0; endif;
  enddo;
  { check unweighted N's }
  Col2Dim( "t2121", t2121, 0,    jtot-2, t2121u, 0 );  { percentages }
  Col2Dim( "t2121", t2121, jmed, jmed,   t2121u, 1 );  { median }

  { Table 2.12.2 processing }
  jtot = tblcol( t2122, totnmed1 = 1 );
  jmax = jtot - 2;
  do j = 0 while j <= jmax
    t2122[*,j] = t2122[*,j] * 100 / t2122[*,jtot];
  enddo;
  t2122[*,jmax+1] = tblsum( column t2122[*,0:jmax] );
  { calculates median }
  jmed = tblcol( t2122, totnmed1 = 2 );
  t2122[*,jmed] = tblmed( discrete column t2122w[*,0:maxeduc] intervals(highest default) );
  { Check for defaults on medians to make them zero }
  itot = tblrow(t2122);
  do i = 0 while i <= itot
    if t2122(i,jmed) = default then t2122(i,jmed) = 0; endif;
  enddo;
  { check unweighted N's }
  Col2Dim( "t2122", t2122, 0,    jtot-2, t2122u, 0 );  { percentages }
  Col2Dim( "t2122", t2122, jmed, jmed,   t2122u, 1 );  { median }

  { Table 2.13 processing }
  t213 = t213 * 100 / t213w;
  { to calculate gender parity index for net attendance }
  jtot = tblcol( t213, attrat = 1 gparity = 1 );
  ifem = tblcol( t213, attrat = 1 hhsex = 2 );
  t213[*,jtot,*] = t213[*,ifem,*] / t213[*,ifem-1,*];
  { to calculate gender parity index for gross attendance }
  jtot = tblcol( t213 );
  ifem = tblcol( t213, attrat = 2 hhsex = 2 );
  t213[*,jtot,*] = t213[*,ifem,*] / t213[*,ifem-1,*];

  { Table 2.13a  processing for figure 2.2 }
  t213a[*,0,*] = 100 * t213a[*,0,*] / t213a[*,1,*];
  
  { Table 2.14 processing }
  t214 = t214 * 100 / t214w;


PROC HOUSEHOLD
preproc

  if HV001 >= 2000 then skip case endif;  { exclude syrian camps }



  { initialize array with children's CMC of birth }
  do i = 1 while i <= 100
    cmcbirth(i) = 0;
  enddo;

  hv024w  = HV024;
  hv025w  = HV025;
  hv025w1 = HV025;
  hv270w  = HV270;
  wreg12  = SHREGION12;

{ -------------------------------------------------------------------- }
{ tables 1.1 }

  wresult  = notappl;
  mresult  = notappl;
  hhsubsam = notappl;
  hhresult = 1;                    { households selected }
  xtab( t101 );
  if HV015 in 1,2,4,5,8 then
    hhresult = 2;                  { households occupied }
    xtab(t101);
    if HV015 = 1 then
      hhresult = 3;                { households interviewed }
      xtab( t101 );
    endif;
  endif;
  hhresult = notappl;
  { !!! Following instructions needed if there is a HH subsample. It is assumed }
  {     that the sub-sample is for men, but it could be related to other topics }
  if HV027 = 1 then 
    hhsubsam = 1;                    { households selected }
    xtab( t101 );
    if HV015 in 1,2,4,5,8 then
      hhsubsam = 2;                  { households occupied }
      xtab(t101);
      if HV015 = 1 then
        hhsubsam = 3;                { households interviewed }
        xtab( t101 );
      endif;
    endif;
    hhsubsam = notappl;
  endif;

  if HV015 <> 1 then skip case endif;

postproc

  if unweight then
    rweight = 1;
  else
    rweight = HV005 / 1000000;
  endif;

{ -------------------------------------------------------------------- }
{ table 2.1.1 }

  { !! this recodification needs to be defined by country managers           }
  { !! following recodification based on categories in the core questionaire }
  {    as defined in te standard recode dictionary for variable HV201        }
  box HV201 => hv201w;
      11,12 => 11;      { piped water into dwelling, yard/plot }
        13  => 12;      { piped to neighbor }
        14  => 13;      { public tap/standpipe }
        21  => 14;      { tube well, borehole }
        31  => 15;      { protected dug well }
        41  => 16;      { protected spring }
        51  => 17;      { rain water }
      61,62 => 18;      { tanker truck/cart with small tank }
        71  => 19;      { bottled water improved }
        32  => 31;      { unprotected well }
        42  => 32;      { unprotected spring }
        43  => 33;      { surface water(River/dam/lake/pond...) }
        96  => 96;      { other }
            => 99;      { missing }
  endbox;
  { round trip duration to water source }
  box  HV204 => hv204w;
       0,996 => 1;      { on premises }
        1-30 => 2;      { 30 minutes or less }
      31-900 => 3;      { more than 30 minutes }
             => 9;      { DK/missing }
  endbox;
  bastreat = ( hv201w in 10:29 & hv204w in 1,2 );
  limtreat = ( hv201w in 10:29 & hv204w in 3 );
  { tabulate households }
  hhandpop = 1;
  xtab( t2011, rweight );
  { tabulate de jure HH members }
  hhandpop = 2;
  xtab( t2011, HV012*rweight );

{ -------------------------------------------------------------------- }
{ table 2.1.2 }

  { !! table based on recodification and variables defined in previous table }
  box hv201w => hv201w2;
      11-29  => 1;      { improved }
      31-39  => 2;      { unimproved }
             => 9;      { missing }
  endbox;
  { tabulate de jure population }
  xtab( t2012, HV012*rweight );
  
{ -------------------------------------------------------------------- }
{ table 2.3.1 }

  { !! this recodification needs to be defined by country managers             }
  {    following recodifications based on categories in the core questionnaire }
  { improved sanitation }
  box  HV205 => hv205w1;
         11  => 11;      { flush/pour to piped sewer system }
         12  => 12;      { flush/pour to septic tank }
         13  => 13;      { flush/pour to a pit latrine }
         15  => 14;      { flush/pour, don't know where }
         21  => 15;      { Ventilated improved pit (VIP) latrine }
         22  => 16;      { pit latrine with a slab }
         41  => 17;      { composting toilet }
             => notappl;
  endbox;
  { not improved }
  box  HV205  => hv205w3;
         14   => 11;      { flush/pour not to sewer/septic tank/pit latrine }
         23   => 12;      { pit latrine without slab /open pit }
         42   => 13;      { bucket toilet }
         43   => 14;      { hanging toilet/hanging latrine }
         96   => 96;      { other }
      missing => 99;      { missing }
              => notappl;
  endbox;
  { no facility/bush/field }
  nofacil = ( HV205 = 31 );
  { basic sanitation service }
  basfacil = ( hv205w1 <> notappl & HV225 = 0 );
  { basic sanitation service }
  limfacil = ( hv205w1 <> notappl & HV238 in 2:95 );
  { location of toilet facility }
  hv238aw = HV238A;
  if HV238A = missing then hv238aw = 9 endif;
  tothh3 = notappl;
  if HV238A <> notappl then tothh3 = 1 endif;
  { tabulate households }
  hhandpop = 1;
  xtab( t2031, rweight );
  { tabulate de jure HH members }
  hhandpop = 2;
  xtab( t2031, HV012*rweight );

{ -------------------------------------------------------------------- }
{ table 2.3.1a }
  
  hv205w3a = notappl;
  hv205w2 = notappl; 
  hv205w5 = notappl; 
  { not shared, improved }
  box HV225 : HV205 => hv205w2;
        0   :   11  => 11;      { flush/pour to piped sewer system }
        0   :   22  => 16;      { pit latrine with a slab }
            :        => notappl;
  endbox;
  { shared, improved }
  box HV225 : HV205 => hv205w5;
        1   :   11  => 11;      { flush/pour to piped sewer system }
        1   :   22  => 16;      { pit latrine with a slab }
            :       => notappl;
  endbox;
  { not improved }
    box  HV205  => hv205w3a;
         14   => 11;      { flush/pour not to sewer/septic tank/pit latrine }
         23   => 12;      { pit latrine without slab /open pit }
         42   => 13;      { bucket toilet }
         43   => 14;      { hanging toilet/hanging latrine }
         31   => 15;
         96   => 96;      { other }
      missing => 99;      { missing }
              => notappl;
  endbox;

  { tabulate households }
  hhandpop = 1;
  xtab( t2031a, rweight );
  { tabulate de jure HH members }
  hhandpop = 2;
  xtab( t2031a, HV012*rweight );

{ -------------------------------------------------------------------- }
{ table 2.3.2 }

  { !! table based on recodification and variables defined in previous table }
  box hv205w1  :  hv205w3  : nofacil => typesani;
     <>notappl :           :         => 1;
               : <>notappl :         => 2;
               :           :    1    => 3;
               :     99    :         => 9;
               :           :         => default;
  endbox;
  xtab( t2032, HV012*rweight );
  
{ -------------------------------------------------------------------- }
{ table 2.4 }

  { electricity }
  box HV206 => hv206w;
        0   => 2;
        1   => 1;
            => 9;
  endbox;
  { flooring }
  hv213w = HV213;
  if HV213 = missing then hv213w = 99 endif;
  { rooms used for sleeping }
  box HV216 => hv216w;
        1   => 1;
        2   => 2;
       3-30 => 3;
            => 9;
  endbox;
  { place for cooking }
  hv241w = HV241;
  if HV241 = notappl then
    hv241w = 4                  { if no food cooked at home }
  elseif HV241 = missing then
     hv241w = 9                 { missing }
  endif;
  { cooking fuel }
  box HV226 => hv226w;
        1   => 1;        { electricity }
       2-4  => 2;        { LPG/natural gas/biogas }
    missing => 99;       { remain values as in core }
            => HV226;
  endbox;
  { using solid fuel for cooking }
  { !! coal/lignite, charcoal, wood/straw/shrub, agricultural crop, animal dung, etc }
  solfuel = ( HV226 in 6:11 );
  { using clean fuel for cooking }
  { !! Electricity, LPG, Natural gas, Biogas, etc }
  clnfuel = ( HV226 in 1:4 );
  { frequency of smoking in the house }
  box HV252 => hv252w;
       1-4  => HV252;    { daily, weekly, monthly, less than monthly }
        0   => 5;        { never }
    missing => 9;        { missing }
            => HV252;    { remain values }
  endbox;
  { tabulate households }
  hhandpop = 1;
  xtab( t204, rweight );
  { tabulate de jure HH members }
  hhandpop = 2;
  xtab( t204, HV012*rweight );

{ -------------------------------------------------------------------- }
{ table 2.5 }

  heffects  = notappl;
  transp    = notappl;
  hv244w    = notappl;
  hv246w    = notappl;
  tnumber   = notappl;
  if HV207  = 1 then heffects = 1; xtab( t205, rweight ); endif;           { radio }
  if HV208  = 1 then heffects = 2; xtab( t205, rweight ); endif;           { TV }
  if HV243A = 1 then heffects = 3; xtab( t205, rweight ); endif;           { mobile phone }
  if HV243E = 1 then heffects = 4; xtab( t205, rweight ); endif;           { computer }
  if HV221  = 1 then heffects = 5; xtab( t205, rweight ); endif;           { non-mobile telephone }
  if HV209  = 1 then heffects = 6; xtab( t205, rweight ); endif;           { refrigerator }
  if SH215A = 1 then heffects = 7; xtab( t205, rweight ); endif;           { Deep Freezer }
  if SH215B = 1 then heffects = 8; xtab( t205, rweight ); endif;           { Gas/Electric oven }
  if SH215C = 1 then heffects = 9; xtab( t205, rweight ); endif;           { Microwave oven }
  if SH215D = 1 then heffects = 10; xtab( t205, rweight ); endif;          { Dishwasher }
  if SH215E = 1 then heffects = 11; xtab( t205, rweight ); endif;          { Garbage dispenser }
  if SH215F = 1 then heffects = 12; xtab( t205, rweight ); endif;          { Washing machine }
  if SH215G = 1 then heffects = 13; xtab( t205, rweight ); endif;          { Drying machine } 
  if SH215H = 1 then heffects = 14; xtab( t205, rweight ); endif;          { Iron }
  if SH215I = 1 then heffects = 15; xtab( t205, rweight ); endif;          { Vacuum Cleaner }
  if SH215K = 1 then heffects = 16; xtab( t205, rweight ); endif;          { Home theater }
  if SH215L = 1 then heffects = 17; xtab( t205, rweight ); endif;          { Tea/Coffee machine }
  if SH215M = 1 then heffects = 18; xtab( t205, rweight ); endif;          { Kettle }
  if SH215N = 1 then heffects = 19; xtab( t205, rweight ); endif;          { Generator }
  if SH215O = 1 then heffects = 20; xtab( t205, rweight ); endif;          { Food processor/Blender }
  if SH215P = 1 then heffects = 21; xtab( t205, rweight ); endif;          { Paid TV services }
  if SH215Q = 1 then heffects = 22; xtab( t205, rweight ); endif;          { Satellite TV }
  if SH215S = 1 then heffects = 23; xtab( t205, rweight ); endif;          { Internet connection }
  if SH215T = 1 then heffects = 24; xtab( t205, rweight ); endif;          { Air Conditioner }
  
  heffects = notappl;
  if HV210  = 1 then transp = 1;   xtab( t205, rweight ); endif;           { bicycle }
  if HV243C = 1 then transp = 2;   xtab( t205, rweight ); endif;           { animal cart }
  if HV211  = 1 then transp = 3;   xtab( t205, rweight ); endif;           { motorcycle }
  if HV212  = 1 then transp = 4;   xtab( t205, rweight ); endif;           { car/truck }
  if HV243D = 1 then transp = 5;   xtab( t205, rweight ); endif;           { boat with motor }
  if SH215V = 1 then transp = 6;   xtab( t205, rweight ); endif;           { commercial vehicle }
  if SH215W = 1 then transp = 7;   xtab( t205, rweight ); endif;           { tractor }
  transp    = notappl;
  hv244w    = ( HV244  = 1 );                                              { owns agricultural land }
  hv246w    = ( HV246  = 1 );                                              { owns farm animals }
  tnumber   = 1;
  xtab( t205, rweight );

{ -------------------------------------------------------------------- }
{ table 2.6 }

  xtab( t206, HV012*rweight );
  { Gini index is tallied in three steps }
  { i = 1, for total }
  { i = 2, for urban/rural residence }
  { i = 3, for regions }
  { IDX points to the proper set of minimum and maximum score values for the background variable to be tallied }
  do i = 1 while i <= 4
    if i = 1 then           { for total }
      hv025w = notappl;
      hv024w = notappl;
      wreg12 = notappl;
      total  = 0;
      idx    = 1;
    elseif i = 2 then       { for urban/rural residence }
      hv025w = HV025;
      hv024w = notappl;
      wreg12 = notappl;
      total  = notappl;
      idx    = 1 + HV025;
    elseif i = 3 then       { for region }
      hv025w = notappl;
      hv024w = HV024;
      wreg12 = notappl;
      total  = notappl;
      idx    = 3 + HV024;
    elseif i = 4 then       { for region }
      hv025w = notappl;
      hv024w = notappl;
      wreg12 = SHREGION12;
      total  = notappl;
      idx    = 8 + SHREGION12;
    endif;
    { Determine tabulation categories as 1/100 of range of wealth scores  }
    wlthrng = Scoremax(idx) - ScoreMin(idx);     { Note that ScoreMin is a negative number }
    wlthgrp = int( ( HV271 - ScoreMin(idx) ) / ( wlthrng / (wlthgrps-1) ) ) + 1;          { Groups numbered from 1-100 }
    if     wlthgrp <        1 then errmsg( "Index %d Factor=%8d min=%8d max=%8d group=%1d", idx, HV271, ScoreMin(idx), ScoreMax(idx), wlthgrp ); wlthgrp = 1
    elseif wlthgrp > wlthgrps then errmsg( "Index %d Factor=%8d min=%8d max=%8d group=%1d", idx, HV271, ScoreMin(idx), ScoreMax(idx), wlthgrp ); wlthgrp = wlthgrps
    endif;
    wigrp = wlthgrp;
    { Tabulate household population and wealth score by wealth groups }
    popwlth = 0; xtab( t206w, rweight*HV012 );
    popwlth = 1; xtab( t206w, rweight*(HV271-ScoreMin(idx)) );
  enddo;
  { reset variables as they were modified in the previous loop }
  hv025w = HV025;
  hv024w = HV024;
  wreg12 = SHREGION12;
  total  = 0;

{ -------------------------------------------------------------------- }
{ tables 2.8, 2.8a (figure 2.1) }

  for i in RECH1_EDT do
    hhsex   = HV104;
    hsex    = HV104;
    if HV104 = missing then hsex = 9 endif;
    box   HV105  => hhage1;
      98,missing => 99;
         80-97   => 16;
                 => int( HV105/5 );
    endbox;
    box HV105 => hhagea;
         0-14 => 1;
        15-64 => 2;
        65-97 => 3;
              => 99;
    endbox;
    box HV105 => hhageb;
         0-17 => 1;
        18-97 => 2;
              => 99;
    endbox;
    adol1019 = ( HV105 in 10:19 );
    if HV103 = 1 then
      xtab( t208,  rweight );
      xtab( t208w, rweight );
      xtab( t208a, rweight );
    endif;
  enddo;

{ -------------------------------------------------------------------- }
{ table 2.9 }

  { counts to calculate mean size of household }
  rowt209 = 1;
  xtab( t209w, rweight );
  rowt209 = 2;
  xtab( t209w, HV012*rweight );

  { de jure household members }
  hv012w = HV012;
  if HV012 > 9 then hv012w = 9 endif;
  { household head sex }
  hv219w  = HV219;
  if HV219 = missing then hv219w = 9 endif;
  { double orphans, de jure children with both parents dead }
  dorphan = ( count( RECH1 where HV105 in 0:17 & HV102 = 1 & HV111 = 0 & HV113 = 0 ) > 0 );
  { single orphans, de jure children with only one parent dead }
  sorphan = ( count( RECH1 where HV105 in 0:17 & HV102 = 1 & ( HV111 = 0 & HV113 <> 0 | HV111 <> 0 & HV113 = 0 ) ) > 0 );
  { foster children, de jure children living with no parents }
  foster  = ( count( RECH1 where HV105 in 0:17 & HV102 = 1 &
                               ( HV112 in 0,missing | HV102(HV112) <> 1 ) &
                               ( HV114 in 0,missing | HV102(HV114) <> 1 ) ) > 0 );
  { foster and/or orphans }
  fostorph = ( foster | dorphan | sorphan );
  xtab( t209, rweight );

{ -------------------------------------------------------------------- }
{ tables 2.10 }

  for i in RECH1_EDT do
    hsex  = HV104;
    if HV104 = missing then hsex = 9 endif;
    if HV102 = 1 & HV105 in 0:17 then                { usual resident (de jure), 0-17 years old }
      mothdead = ( HV111 = 0 );
      fathdead = ( HV113 = 0 );
      mothaliv = ( HV111 = 1 );
      livemoth = ( HV112 in 1:HV009 & HV102(HV112) = 1 );   { mother in the household and de-jure }
      fathaliv = ( HV113 = 1 );
      livefath = ( HV114 in 1:HV009 & HV102(HV114) = 1 );   { father in the household and de-jure }
      total15  = ( HV105 in 0:14 );     { children < 15 }
      total18  = 1;                     { children < 18 }
      box HV105   => hhage18;
            0-1   => 1;
            2-4   => 2;
            5-9   => 3;
           10-14  => 4;
                  => 5;
      endbox;
      box  mothaliv : livemoth : fathaliv : livefath => colt210;
                    :    1     :          :     1    => 1;   { live with both parents      }
                    :    1     :    1     :          => 2;   { live mother  - father alive }
                    :    1     :          :          => 3;   {              - father dead  }
              1     :          :          :     1    => 4;   { live father  - mother alive }
                    :          :          :     1    => 5;   {              - mother dead  }
              1     :          :    1     :          => 6;   { live neither - both alive   }
                    :          :    1     :          => 7;   {              - father alive }
              1     :          :          :          => 8;   {              - mother alive }
                    :          :          :          => 9;   {              - none alive   }
      endbox;
      if special( HV111 ) | HV111 = 8 |        { missing/DK in either }
         special( HV113 ) | HV113 = 8 then     { mother/father alive  }
        colt210 = 99
      endif;
      { living with both parents }
      box  colt210 => colt210a;
              1    => colt210;
                   => notappl;
      endbox;
      { living with mother }
      box  colt210 => colt210b;
             2-3   => colt210 - 1;
                   => notappl;
      endbox;
      { living with father }
      box  colt210 => colt210c;
             4-5   => colt210 - 3;
                   => notappl;
      endbox;
      { not living with either parent }
      box  colt210 => colt210d;
             6-9   => colt210 - 5;
              99   => 9;
                   => notappl;
      endbox;
      { percentage with one or both parents dead }
      totperc1 = notappl;
      if HV111 = 0 | HV113 = 0 then totperc1 = 2 endif;
      xtab( t210, rweight );
      xtab( t210u );

    endif;       { end de-jure children age 0-17 }
  enddo;

{ -------------------------------------------------------------------- }
{ table 2.11 }

{!!! this information is at individual level }
{  for i in RECH1_EDT do
    if HV102 = 1 & HV105 in 0:4 then      { de-jure children < 5 }
      hsex = HV104;       { sex }
      if HV104 = missing then hsex = 9 endif;
      box HV105 => hhage4;
           0-1  => 1;
                => 2;
      endbox;
      { birth certificate }
      box HV140 => hv140w;
             1  => 1;      { has a birth certificate }
             2  => 2;      { registered, didn't have birth certificate }
                => notappl;
      endbox;
      xtab( t211, rweight );
      xtab( t211u );
    endif;
  enddo;
***}
{ -------------------------------------------------------------------- }
{ tables 2.12.1 & 12.12.2 }

  for i in RECH1_EDT do
    if HV103 = 1 & HV105 in 6:98,missing then      { de facto population 4+ (6+ core) years old including missing }
      if HV105 in 98,missing then
        hhage3 = 14
      elseif HV105 > 65 then
        hhage3 = 13
      else
        hhage3 = int( HV105/5 );
      endif;
      hheduc = SHEDUC(i);        { originally HV109 }
      if special( SHEDUC(i) ) | SHEDUC(i) = 8 then hheduc = 9 endif;
      { for women }
      if HV104 = 2 then
        xtab( t2121, rweight );
        coltotu = 1;
        xtab( t2121u );
        if  HV108 in 0:96 then
          educmed = HV108;
          if educmed > maxeduc then educmed = maxeduc endif;
          xtab( t2121w, rweight );
          coltotu = 2;
          xtab( t2121u );
        endif;
      endif;
      { for men }
      if HV104 = 1 then
        xtab( t2122, rweight );
        coltotu = 1;
        xtab( t2122u );
        if HV108 in 0:96 then
          educmed = HV108;
          if educmed > maxeduc then educmed = maxeduc endif;
          xtab( t2122w, rweight );
          coltotu = 2;
          xtab( t2122u );
        endif;
      endif;
    endif;                       { end de facto 4+ (6+ core) years old }
  enddo;

{ -------------------------------------------------------------------- }
{ table 2.13, 2.13a (figure 2.2) }

  { adjust the the country's CMC school year when the survey goes across two school calendar years }
  cmceducf = cmceduci;
  if HV008 >= cmceduci+12 then cmceducf = cmceduci + 12 endif;
  for i in RECH1_EDT do
    hhsex  = HV104;
    hsex   = HV104;
    { calculate age at the beginning of country's school year }
    if cmcbirth(i) <> 0 then
      ageatsch = int( (cmceducf-cmcbirth(i)) / 12 );
    else
      { impute an age at the beginnig of the school year when CMC of birth unknown }
      xtemp    = HV008 - HV105*12;
      cmctemp  = random( xtemp-11, xtemp );
      ageatsch = int( (cmceducf-cmctemp) / 12 );
    endif;
    if HV103 = 1 & HV105 in 6:24 then      { de facto population 5-24 ( !! check if country asks for 6-24) }
      { !! check primary + secondary school age for the country and adjust it }
      if ageatsch in 6:13 then
        schlev = 1;                             { primary }
        attrat = 2;                             { denominator kids 7-12 for gross }
        xtab( t213w, rweight );
        attrat = 1;                             { denominator kids 7-12 for net }
        xtab( t213w, rweight );
        if SHEDCUR(i) in 1:2 then                    { in primary original HV122 prim/sec/high HV122 = 1 }
          xtab( t213, rweight );                { numerator 7-12 for net }
        endif;
      endif;
      { !! check secondary school age for the country and adjust it }
      if ageatsch in 14:17 then
        schlev = 2;                             { secondary }
        attrat = 2;                             { denominator kids 13-18 for gross }
        xtab( t213w, rweight );
        attrat = 1;                             { denominator kids 13-18 for net   }
        xtab( t213w, rweight );
        if SHEDCUR(i) = 3 then                       { in secondary original HV122 prim/sec/high HV122 = 2 }
          xtab( t213, rweight );                { numerator 13-18 for net }
        endif;
      endif;
      { numerator all in school for gross attendance ratio }
      schlev = notappl;
      attrat = 2;
      if SHEDCUR(i) in 1:2 then                       { in primary }
        schlev = 1;
      elseif SHEDCUR(i) = 3 then                   { in secondary }
        schlev = 2;
      endif;
      xtab( t213, rweight );

      { table 2.13a for figure 2.2 }
      agehhs = HV105;
      colt213a = 2;
      xtab( t213a, rweight );
      if HV121 in 1,2 & SHEDCUR(i) <> 0 then
        colt213a = 1;
        xtab( t213a, rweight );
      endif;
    endif;                    { end de facto 5-24 }
  enddo;


{ -------------------------------------------------------------------- }
{ table 2.14 }
 
  for i in RECH1_EDT do
     hhsex1  = HV104;
     
     if HV103 = 1 & HV105 in 6:24 then
        grdcur  = HV123;
        grdprev = HV127;
        if SH23A(i) in 1 & grdprev in 1:95 then
          repdrop = 1;                        { repetition }
          colt214a = grdprev;
          xtab( t214w, rweight );
          if SH21A(i) in 1 & grdcur in 0:95 & grdcur = grdprev then
             xtab( t214, rweight );
          endif;
          repdrop = 2;                        { dropout }
          colt214a = grdprev;
          xtab( t214w, rweight );
          if HV121 = 0 then
            xtab( t214, rweight );
          endif;
        endif;
     endif;                               { end of de-facto 6:24 children }
  enddo;


PROC WOMAN
preproc

{ -------------------------------------------------------------------- }
{ tables 1.1 continuation }

  wresult = 1;                     { all women }
  xtab( t101 );
  if V015 = 1 then
    wresult = 2;                   { women interviewed }
    xtab( t101 );
  endif;

  if V015 <> 1 then skip case endif;

  { store children's CMC of birth to be used in level 1 to calculate NAR and GAR in table 2.13 }
  for i in REC21_EDT do
    if B16 in 1:HV009 then
      cmcbirth(B16) = B3
    endif
  enddo;


postproc

  v102w    = V102;
  v101w    = V101;
  wreg12   = SHREGION12;
  v190w    = V190;


  if unweight then
    rweight = 1;
  else
    rweight = V005 / 1000000;
  endif;


{ table 2.11 }

for i in REC21_EDT do 
   if B16 in 1:HV009 then 
    if HV102(B16) = 1 & B8 in 0:4 then      { de-jure children < 5 }
      sex1 = B4(i);       { sex }
      box  B8(i) => chiage4;
           0-1   => 1;
                 => 2;
      endbox;
      { birth certificate }
      box s223(i) => s223w;
               1  => 1;      { has a birth certificate }
               0  => 2;      { didn't have birth certificate }
         missing  => 9;
      endbox;
      xtab( t211, rweight );
      xtab( t211u );
    endif;
   endif;
 enddo;




